Index

C G I N P S 
All Classes and Interfaces|All Packages

C

client(Class<? extends Authorizer>, Class<? extends Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a default security filter.
client(Class<? extends Authorizer>, Function<Config, Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a default security filter.
client(Class<? extends Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a default security filter.
client(String, Class<? extends Authorizer>, Class<? extends Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a security filter under the given path.
client(String, Class<? extends Authorizer>, Function<Config, Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a security filter under the given path.
client(String, Class<? extends Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a security filter under the given path.
client(String, String, Class<? extends Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a filter under the given path.
client(String, String, Function<Config, Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a filter under the given path.
client(String, Function<Config, Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a security filter under the given path.
client(String, Authorizer, Class<? extends Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a security filter under the given path.
client(String, Authorizer, Function<Config, Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a security filter under the given path.
client(Function<Config, Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a default security filter.
client(Authorizer, Class<? extends Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a default security filter.
client(Authorizer, Function<Config, Client>) - Method in class io.jooby.pac4j.Pac4jModule
Register a default security filter.
create(Context) - Static method in interface io.jooby.pac4j.Pac4jContext
Wrap a Web context as pac4j context.

G

getCallbackPath() - Method in class io.jooby.pac4j.Pac4jOptions
Callback path, defaults to /callback.
getContext() - Method in interface io.jooby.pac4j.Pac4jContext
Get underlying context.
getCookieSameSite() - Method in class io.jooby.pac4j.Pac4jOptions
Returns the 'SameSite' parameter value used for cookies generated by the pac4j security engine.
getDefaultClient() - Method in class io.jooby.pac4j.Pac4jOptions
Default client to use.
getDefaultUrl() - Method in class io.jooby.pac4j.Pac4jOptions
Default url to redirect to after successful login.
getLogoutPath() - Method in class io.jooby.pac4j.Pac4jOptions
Callback path, defaults to /logout.
getMultiProfile() - Method in class io.jooby.pac4j.Pac4jOptions
Whether multi profiles are supported.
getRenewSession() - Method in class io.jooby.pac4j.Pac4jOptions
Whether the session must be renewed.
getSaveInSession() - Method in class io.jooby.pac4j.Pac4jOptions
True to save profile/user data into session.
getSessionStore() - Method in interface io.jooby.pac4j.Pac4jContext
 

I

install(Jooby) - Method in class io.jooby.pac4j.Pac4jModule
 
io.jooby.pac4j - module io.jooby.pac4j
Pac4j module
io.jooby.pac4j - package io.jooby.pac4j
 
isCentralLogout() - Method in class io.jooby.pac4j.Pac4jOptions
Central logout option.
isDestroySession() - Method in class io.jooby.pac4j.Pac4jOptions
Whether to destroy session after logout.
isForceCallbackRoutes() - Method in class io.jooby.pac4j.Pac4jOptions
The /callback routes are off when pac4j is configured with DirectClient clients only.
isForceLogoutRoutes() - Method in class io.jooby.pac4j.Pac4jOptions
The /logout routes are off when pac4j is configured with DirectClient clients only.
isLocalLogout() - Method in class io.jooby.pac4j.Pac4jOptions
Local logout option.

N

newActionAdapter() - Static method in class io.jooby.pac4j.Pac4jModule
Default action adapter.
newCallbackLogic(Set<String>) - Static method in class io.jooby.pac4j.Pac4jModule
Default callback logic and optionally specify the pattern to excludes while saving user requested urls.
newLogoutLogic() - Static method in class io.jooby.pac4j.Pac4jModule
Creates a default logout logic.
newSecurityLogic(Set<String>) - Static method in class io.jooby.pac4j.Pac4jModule
Default security logic and optionally specify the pattern to excludes while saving user requested urls.
newUrlResolver() - Static method in class io.jooby.pac4j.Pac4jModule
Default url resolver.

P

Pac4jContext - Interface in io.jooby.pac4j
Pac4j web context.
Pac4jModule - Class in io.jooby.pac4j
Pac4j module: https://jooby.io/modules/pac4j.
Pac4jModule() - Constructor for class io.jooby.pac4j.Pac4jModule
Creates a new pac4j module.
Pac4jModule(Pac4jOptions) - Constructor for class io.jooby.pac4j.Pac4jModule
Creates a new pac4j module.
Pac4jModule(Pac4jOptions, Config) - Constructor for class io.jooby.pac4j.Pac4jModule
Creates a new pac4j module.
Pac4jModule(Config) - Constructor for class io.jooby.pac4j.Pac4jModule
Creates a new pac4j module.
Pac4jOptions - Class in io.jooby.pac4j
Options to configure pac4j security, callback and logout actions.
Pac4jOptions() - Constructor for class io.jooby.pac4j.Pac4jOptions
 

S

setCallbackPath(String) - Method in class io.jooby.pac4j.Pac4jOptions
Set callback path.
setCentralLogout(boolean) - Method in class io.jooby.pac4j.Pac4jOptions
Set central logout option.
setCookieSameSite(SameSite) - Method in class io.jooby.pac4j.Pac4jOptions
Sets the 'SameSite' parameter value used for cookies generated by the pac4j security engine, pass null to omit the parameter.
setDefaultClient(String) - Method in class io.jooby.pac4j.Pac4jOptions
Set default client to use.
setDefaultUrl(String) - Method in class io.jooby.pac4j.Pac4jOptions
Set default url to redirect to after successful login.
setDestroySession(boolean) - Method in class io.jooby.pac4j.Pac4jOptions
Set destroy session logout option.
setForceCallbackRoutes(boolean) - Method in class io.jooby.pac4j.Pac4jOptions
 
setForceLogoutRoutes(boolean) - Method in class io.jooby.pac4j.Pac4jOptions
 
setLocalLogout(boolean) - Method in class io.jooby.pac4j.Pac4jOptions
Set logout option.
setLogoutPath(String) - Method in class io.jooby.pac4j.Pac4jOptions
Set logout path.
setMultiProfile(Boolean) - Method in class io.jooby.pac4j.Pac4jOptions
Set Whether multi profiles are supported.
setRenewSession(Boolean) - Method in class io.jooby.pac4j.Pac4jOptions
Set whether the session must be renewed.
setSaveInSession(Boolean) - Method in class io.jooby.pac4j.Pac4jOptions
Set whenever profile/data must be save in HTTP session.
C G I N P S 
All Classes and Interfaces|All Packages